@@ -29,7 +29,7 @@ if ty.TYPE_CHECKING:  # pragma: no cover
 logger = logging.getLogger("arcana")
 
 
-@attrs.define
+@attrs.define(kw_only=True)
 class Dataset:
     """
     A representation of a "dataset", the complete collection of data
@@ -43,6 +43,12 @@ class Dataset:
     store : Repository
         The store the dataset is stored into. Can be the local file
         system by providing a MockRemote repo.
+    space: DataSpace
+        The space of the dataset. See https://arcana.readthedocs.io/en/latest/data_model.html#spaces)
+        for a description
+    id_patterns : dict[str, str]
+        Patterns for inferring IDs of rows not explicitly present in the hierarchy of
+        the data tree. See ``DataStore.infer_ids()`` for syntax
     hierarchy : list[str]
         The data frequencies that are explicitly present in the data tree.
         For example, if a MockRemote dataset (i.e. directory) has
@@ -59,7 +65,7 @@ class Dataset:
             ['subject', 'session']
 
         In such cases, if there are multiple timepoints, the timepoint ID of the
-        session will need to be extracted using the `id_composition` argument.
+        session will need to be extracted using the `id_patterns` argument.
 
         Alternatively, the hierarchy could be organised such that the tree
         first splits on longitudinal time-points, then a second directory layer
@@ -72,27 +78,8 @@ class Dataset:
         space defined in the DataSpace enum, i.e. the "bitwise or" of the
         layer values of the hierarchy must be 1 across all bits
         (e.g. 'session': 0b111).
-    space: DataSpace
-        The space of the dataset. See https://arcana.readthedocs.io/en/latest/data_model.html#spaces)
-        for a description
-    id_composition : dict[str, str]
-        Not all IDs will appear explicitly within the hierarchy of the data
-        tree, and some will need to be inferred by extracting components of
-        more specific labels.
-
-        For example, given a set of subject IDs that combination of the ID of
-        the group that they belong to and the member ID within that group
-        (i.e. matched test & control would have same member ID)
-
-            CONTROL01, CONTROL02, CONTROL03, ... and TEST01, TEST02, TEST03
-
-        the group ID can be extracted by providing the a list of tuples
-        containing ID to source the inferred IDs from coupled with a regular
-        expression with named groups
-
-            id_composition = {
-                'subject': r'(?P<group>[A-Z]+)(?P<member>[0-9]+)')
-            }
+    metadata : dict or DatasetMetadata
+        Generic metadata associated with the dataset, e.g. authors, funding sources, etc...
     include : list[tuple[DataSpace, str or list[str]]]
         The IDs to be included in the dataset per row_frequency. E.g. can be
         used to limit the subject IDs in a project to the sub-set that passed
@@ -107,8 +94,8 @@ class Dataset:
     columns : list[tuple[str, DataSource or DataSink]
         The sources and sinks to be initially added to the dataset (columns are
         explicitly added when workflows are applied to the dataset).
-    workflows : Dict[str, pydra.Workflow]
-        Workflows that have been applied to the dataset to generate sink
+    pipelines : dict[str, pydra.Workflow]
+        Pipelines that have been applied to the dataset to generate sink
     access_args: ty.Dict[str, Any]
         Repository specific args used to control the way the dataset is accessed
     """
@@ -120,19 +107,19 @@ class Dataset:
     id: str = attrs.field(converter=str, metadata={"asdict": False})
     store: datastore.DataStore = attrs.field()
     space: DataSpace = attrs.field()
+    id_patterns: dict[str, str] = attrs.field(
+        factory=dict, converter=default_if_none(factory=dict)
+    )
     hierarchy: ty.List[DataSpace] = attrs.field(converter=list)
     metadata: DatasetMetadata = attrs.field(
         factory=DatasetMetadata,
         converter=metadata_converter,
         repr=False,
     )
-    id_composition: dict[str, str] = attrs.field(
-        factory=dict, converter=default_if_none(factory=dict)
-    )
-    include: ty.List[ty.Tuple[DataSpace, str or list[str]]] = attrs.field(
+    include: dict[str, ty.Union[list[str], str]] = attrs.field(
         factory=dict, converter=default_if_none(factory=dict), repr=False
     )
-    exclude: ty.List[ty.Tuple[DataSpace, str or list[str]]] = attrs.field(
+    exclude: dict[str, ty.Union[list[str], str]] = attrs.field(
         factory=dict, converter=default_if_none(factory=dict), repr=False
     )
     name: str = attrs.field(default="")
@@ -146,10 +133,6 @@ class Dataset:
 
     def __attrs_post_init__(self):
         self.tree.dataset = self
-        # Ensure the keys of the include, exclude and id_composition attrs are
-        # in the space of the dataset
-        self.include = [(self.space[str(k)], v) for k, v in self.include]
-        self.exclude = [(self.space[str(k)], v) for k, v in self.exclude]
         # Set reference to pipeline in columns and pipelines
         for column in self.columns.values():
             column.dataset = self
@@ -177,20 +160,48 @@ class Dataset:
         ]
         if wrong_freq:
             raise ArcanaUsageError(
-                f"Data hierarchy of {wrong_freq} column specs do(es) not match"
-                f" that of dataset {self.space}"
+                f"Data hierarchy of {wrong_freq} column specs do(es) not match "
+                f"that of dataset {self.space}"
             )
 
-    @exclude.validator
-    def exclude_validator(self, _, exclude):
-        include_freqs = set(f for f, i in self.include if i is not None)
-        exclude_freqs = set(f for f, i in exclude if i is not None)
-        both = include_freqs & exclude_freqs
-        if both:
+    @include.validator
+    def include_validator(self, _, include: dict[str, ty.Union[str, list[str]]]):
+        valid = set(str(f) for f in self.space)
+        freqs = set(include)
+        unrecognised = freqs - valid
+        if unrecognised:
             raise ArcanaUsageError(
-                "Cannot provide both 'include' and 'exclude' arguments "
-                "for frequencies ('{}') to Dataset".format("', '".join(both))
+                f"Unrecognised frequencies in 'include' dictionary provided to {self}: "
+                + ", ".join(unrecognised)
             )
+        self._validate_criteria(include, "inclusion")
+
+    @exclude.validator
+    def exclude_validator(self, _, exclude: dict[str, ty.Union[str, list[str]]]):
+        valid = set(self.hierarchy)
+        freqs = set(exclude)
+        unrecognised = freqs - valid
+        if unrecognised:
+            raise ArcanaUsageError(
+                f"Unrecognised frequencies in 'exclude' dictionary provided to {self}, "
+                "only frequencies present in the dataset hierarchy are allowed: "
+                + ", ".join(unrecognised)
+            )
+        self._validate_criteria(exclude, "exclusion")
+
+    def _validate_criteria(self, criteria, type_):
+        for freq, criterion in criteria.items():
+            try:
+                re.compile(criterion)
+            except Exception:
+                if not isinstance(criterion, list) or any(
+                    not isinstance(x, str) for x in criterion
+                ):
+                    raise ArcanaUsageError(
+                        f"Unrecognised {type_} criterion for '{freq}' provided to {self}, "
+                        f"{criterion}, should either be a list of ID strings or a valid "
+                        "regular expression"
+                    )
 
     @hierarchy.validator
     def hierarchy_validator(self, _, hierarchy):
@@ -221,25 +232,37 @@ class Dataset:
                 + "', '".join(str(m) for m in (covered ^ max(self.space)).span())
                 + f"'] the '{self.space.__module__}.{self.space.__name__}' data space"
             )
+        # if missing_axes:
+        #     raise ArcanaDataTreeConstructionError(
+        #         "Leaf node at %s is missing explicit IDs for the following axes, %s"
+        #         ", they will be set to None, noting that an error will be raised if there "
+        #         " multiple nodes for this session. In that case, set 'id-patterns' on the "
+        #         "dataset to extract the missing axis IDs from composite IDs or row "
+        #         "metadata",
+        #         tree_path,
+        #         missing_axes,
+        #     )
+        #     for m in missing_axes:
+        #         ids[m] = None
 
-    @id_composition.validator
-    def id_composition_validator(self, _, id_composition):
-        non_valid_keys = [f for f in id_composition if f not in self.space.__members__]
+    @id_patterns.validator
+    def id_patterns_validator(self, _, id_patterns):
+        non_valid_keys = [f for f in id_patterns if f not in self.space.__members__]
         if non_valid_keys:
             raise ArcanaWrongDataSpaceError(
-                f"Keys for the id_composition dictionary {non_valid_keys} are not part "
+                f"Keys for the id_patterns dictionary {non_valid_keys} are not part "
                 f"of the {self.space} data space"
             )
-        for key, expr in id_composition.items():
+        for key, expr in id_patterns.items():
             groups = list(re.compile(expr).groupindex)
             non_valid_groups = [f for f in groups if f not in self.space.__members__]
             if non_valid_groups:
                 raise ArcanaWrongDataSpaceError(
-                    f"Groups in the {key} id_composition expression {non_valid_groups} "
+                    f"Groups in the {key} id_patterns expression {non_valid_groups} "
                     f"are not part of the {self.space} data space"
                 )
 
-    def save(self, name=None):
+    def save(self, name=""):
         self.store.save_dataset(self, name=name)
 
     @classmethod
@@ -322,8 +345,14 @@ class Dataset:
         return locator
 
     def add_source(
-        self, name, datatype, path=None, row_frequency=None, overwrite=False, **kwargs
-    ):
+        self,
+        name: str,
+        datatype: type,
+        path: str = None,
+        row_frequency: str = None,
+        overwrite: bool = False,
+        **kwargs,
+    ) -> DataSource:
         """Specify a data source in the dataset, which can then be referenced
         when connecting workflow inputs.
 
@@ -350,15 +379,22 @@ class Dataset:
         source = DataSource(
             name=name,
             datatype=datatype,
-            row_frequency=row_frequency,
             path=path,
+            row_frequency=row_frequency,
             dataset=self,
             **kwargs,
         )
-        self._add_spec(name, source, overwrite)
+        self._add_column(name, source, overwrite)
         return source
 
-    def add_sink(self, name, datatype, row_frequency=None, overwrite=False, **kwargs):
+    def add_sink(
+        self,
+        name: str,
+        datatype: type,
+        row_frequency: str = None,
+        overwrite: bool = False,
+        **kwargs,
+    ) -> DataSink:
         """Specify a data source in the dataset, which can then be referenced
         when connecting workflow inputs.
 
@@ -370,13 +406,14 @@ class Dataset:
         datatype : type
             The file-format (for file-sets) or datatype (for fields)
             that the sink will be stored in within the dataset
-        row_frequency : DataSpace, default self.leaf_freq
-            The row_frequency of the sink within the dataset
-        overwrite : bool
-            Whether to overwrite an existing sink
         path : str, optional
             Specify a particular for the sink within the dataset, defaults to the column
             name within the dataset derivatives directory of the store
+        row_frequency : str, optional
+            The row_frequency of the sink within the dataset, by default the leaf
+            frequency of the data tree
+        overwrite : bool
+            Whether to overwrite an existing sink
         """
         row_frequency = self.parse_frequency(row_frequency)
         sink = DataSink(
@@ -386,10 +423,10 @@ class Dataset:
             dataset=self,
             **kwargs,
         )
-        self._add_spec(name, sink, overwrite)
+        self._add_column(name, sink, overwrite)
         return sink
 
-    def _add_spec(self, name, spec, overwrite):
+    def _add_column(self, name: str, spec, overwrite):
         if name in self.columns:
             if overwrite:
                 logger.info(
@@ -475,9 +512,9 @@ class Dataset:
 
         Parameters
         ----------
-        frequency : DataSpace or None
-            The "frequency" of the rows, e.g. per-session, per-subject. If
-            None then all rows are returned
+        frequency : DataSpace, optional
+            The "frequency" of the rows, e.g. per-session, per-subject, defaults to
+            leaf rows
         ids : Sequence[str or Tuple[str]]
             The i
 
@@ -498,7 +535,7 @@ class Dataset:
                 rows = (n for n in rows if n.id in set(ids))
             return rows
 
-    def row_ids(self, frequency: str):
+    def row_ids(self, frequency: str = None):
         """Return all the IDs in the dataset for a given row_frequency
 
         Parameters
@@ -511,10 +548,13 @@ class Dataset:
         Sequence[str]
             The IDs of the rows
         """
-        with self.tree:
+        if frequency is None:
+            frequency = max(self.space)  # "leaf" nodes of the data tree
+        else:
             frequency = self.parse_frequency(frequency)
-            if frequency == self.root_freq:
-                return [None]
+        if frequency == self.root_freq:
+            return [None]
+        with self.tree:
             return self.root.children[frequency].keys()
 
     def __getitem__(self, name):
@@ -760,34 +800,10 @@ class Dataset:
         )
         return File(column.match_entry(dataset.root).item)
 
-    @classmethod
-    def decompose_ids(cls, ids: dict[str, str], composition: dict[str, str]):
-        """Infer IDs from those explicitly provided by using the decomposition patterns
-
-        Parameters
-        ----------
-        ids : dict[str, str]
-            explicitly provided IDs
-        composition : dict[str, str]
-            patterns used to inferred composed IDs
-
-        Return
-        ------
-        inferred_ids : dict[str, str]
-            IDs inferred from the decomposition
-        """
-        inferred_ids = {}
-        if composition is not None:
-            for freq, regex in composition.items():
-                match = re.match(regex, ids[freq])
-                inferred_ids.update(match.groupdict())
-            conflicting = set(ids) & set(inferred_ids)
-            if conflicting:
-                raise ArcanaUsageError(
-                    "Inferred IDs from decomposition conflict with explicitly provided IDs: "
-                    + str(conflicting)
-                )
-        return inferred_ids
+    def infer_ids(self, ids: dict[str, str], metadata: dict[str, dict[str, str]]):
+        return self.store.infer_ids(
+            ids=ids, id_patterns=self.id_patterns, metadata=metadata
+        )
 
 
 @attrs.define
