@@ -17,7 +17,6 @@ from arcana.core.utils.serialize import (
     ObjectListConverter,
     ClassResolver,
 )
-from arcana.core.data.type import BaseDirectory
 from ..command.base import ContainerCommand
 from .base import ArcanaImage
 from .components import ContainerAuthor, License, KnownIssue
@@ -69,8 +68,7 @@ class App(ArcanaImage):
         the file the spec was loaded from, if applicable
     """
 
-    SPEC_PATH = "/arcana-spec.yaml"
-    IN_DOCKER_ARCANA_HOME_DIR = "/arcana-home"
+    IN_DOCKER_SPEC_PATH = "/arcana-spec.yaml"
 
     SUBPACKAGE = "deploy"
 
@@ -196,7 +194,9 @@ class App(ArcanaImage):
             path to build dir
         """
         self.save(build_dir / "arcana-spec.yaml")
-        dockerfile.copy(source=["./arcana-spec.yaml"], destination=self.SPEC_PATH)
+        dockerfile.copy(
+            source=["./arcana-spec.yaml"], destination=self.IN_DOCKER_SPEC_PATH
+        )
 
     def save(self, yml_path: Path):
         """Saves the specification to a YAML file that can be loaded again
@@ -403,7 +403,11 @@ class App(ArcanaImage):
 
             f.write("#### Inputs\n")
             tbl_inputs = MarkdownTable(
-                f, "Name", "Data type", "Stored data type default", "Description"
+                f,
+                "Name",
+                "Required data-type",
+                "Default column data-type",
+                "Description",
             )
             if self.command.inputs is not None:
                 for inpt in self.command.inputs:
@@ -417,7 +421,11 @@ class App(ArcanaImage):
 
             f.write("#### Outputs\n")
             tbl_outputs = MarkdownTable(
-                f, "Name", "Data type", "Stored data type default", "Description"
+                f,
+                "Name",
+                "Required data-type",
+                "Default column data-type",
+                "Description",
             )
             if self.command.outputs is not None:
                 for outpt in self.command.outputs:
@@ -478,7 +486,7 @@ class App(ArcanaImage):
         return diff
 
     # @classmethod
-    # def load_in_image(cls, spec_path: Path = SPEC_PATH):
+    # def load_in_image(cls, spec_path: Path = IN_DOCKER_SPEC_PATH):
     #     yml_dct = cls._load_yaml(spec_path)
     #     klass = ClassResolver(cls)(yml_dct.pop("type"))
     #     return klass.load(yml_dct)
@@ -486,23 +494,11 @@ class App(ArcanaImage):
     @classmethod
     def _data_format_html(cls, datatype):
 
-        if isinstance(datatype, str):
-            module, name = datatype.split(":")
-            name = name.lower()
-            text = f"{name} (from '{module}' extension)"
-        else:
-            if ext := getattr(datatype, "ext", None):
-                text = f"{datatype.desc} (`.{ext}`)"
-            elif getattr(datatype, "is_dir", None) and datatype is not BaseDirectory:
-                text = f"{datatype.desc} (directory)"
-            else:
-                text = datatype.desc
-
-            name = datatype.__name__.lower()
+        datatype_str = datatype.mime_like if not isinstance(datatype, str) else datatype
 
         return (
-            f'<span data-toggle="tooltip" data-placement="bottom" title="{name}" '
-            f'aria-label="{name}">{text}</span>'
+            f'<span data-toggle="tooltip" data-placement="bottom" title="{datatype_str}" '
+            f'aria-label="{datatype_str}">{datatype_str}</span>'
         )
 
     DOCKERFILE_README_TEMPLATE = """
