@@ -60,6 +60,8 @@ class ArcanaImage:
     labels : dict[str, str]
     """
 
+    IN_DOCKER_ARCANA_HOME_DIR = "/arcana-home"
+
     name: str
     version: str = attrs.field(converter=str)
     build_iteration: str = None
@@ -178,6 +180,10 @@ class ArcanaImage:
 
         self.add_labels(dockerfile)
 
+        # Create Arcana Home directory
+        dockerfile.run(f"mkdir {self.IN_DOCKER_ARCANA_HOME_DIR}")
+        dockerfile.env(ARCANA_HOME=self.IN_DOCKER_ARCANA_HOME_DIR)
+
         return dockerfile
 
     @classmethod
