@@ -4,10 +4,20 @@ import docker
 import docker.errors
 from arcana.core.utils.misc import show_cli_trace
 from arcana.core.cli.deploy import make_app, install_license
-from arcana.core.deploy.image import App
-from arcana.core.data.set.base import Dataset
-from arcana.core.data import Samples
-from arcana.dirtree import DirTree
+from arcana.testing.deploy.licenses import (
+    get_pipeline_image,
+    make_dataset,
+    ORG,
+    REGISTRY,
+    IMAGE_VERSION,
+    LICENSE_CONTENTS,
+    LICENSE_NAME,
+    LICENSE_INPUT_FIELD,
+    LICENSE_OUTPUT_FIELD,
+    LICENSE_PATH_PARAM,
+    LICENSE_INPUT_PATH,
+    LICENSE_OUTPUT_PATH,
+)
 
 
 def test_buildtime_license(license_file, run_prefix: str, work_dir: Path, cli_runner):
@@ -35,7 +45,7 @@ def test_buildtime_license(license_file, run_prefix: str, work_dir: Path, cli_ru
         make_app,
         args=[
             str(root_dir),
-            "core:App",
+            "stdlib:App",
             "--build-dir",
             str(build_dir),
             "--license",
@@ -142,70 +152,6 @@ def test_dataset_runtime_license(license_file, run_prefix, work_dir, cli_runner)
     )
 
 
-def get_pipeline_image(license_path) -> App:
-    return App(
-        name="to_be_overridden",
-        org=ORG,
-        version="1.0",
-        authors=[{"name": "Some One", "email": "some.one@an.email.org"}],
-        info_url="http://concatenate.readthefakedocs.io",
-        description="A test of the license installation",
-        readme="This is a test README",
-        packages={
-            "pip": ["fileformats"],
-        },
-        licenses={
-            LICENSE_NAME: {
-                "destination": license_path,
-                "info_url": "http://license.test",
-                "description": "This is a license to test the build structure",
-            }
-        },
-        command={
-            "task": "arcana.testing.tasks:check_license",
-            "row_frequency": "core:Samples[sample]",
-            "inputs": [
-                {
-                    "name": LICENSE_INPUT_FIELD,
-                    "datatype": "fileformats.text:Plain",
-                    "field": "expected_license_contents",
-                    "help_string": "the path to the license",
-                },
-            ],
-            "outputs": [
-                {
-                    "name": LICENSE_OUTPUT_FIELD,
-                    "datatype": "fileformats.text:Plain",
-                    "field": "out",
-                    "help_string": "the validated license path",
-                }
-            ],
-            "parameters": [
-                {
-                    "name": LICENSE_PATH_PARAM,
-                    "datatype": "str",
-                    "field": "expected_license_path",
-                    "required": True,
-                    "help_string": "the expected contents of the license file",
-                }
-            ],
-        },
-    )
-
-
-def make_dataset(dataset_dir) -> Dataset:
-
-    contents_dir = dataset_dir / "sample1"
-    contents_dir.mkdir(parents=True)
-
-    with open(contents_dir / (LICENSE_INPUT_PATH + ".txt"), "w") as f:
-        f.write(LICENSE_CONTENTS)
-
-    dataset = DirTree().define_dataset(dataset_dir, space=Samples)
-    dataset.save()
-    return dataset
-
-
 @pytest.fixture
 def license_file(work_dir) -> Path:
     license_src = work_dir / "license_file.txt"
@@ -214,23 +160,3 @@ def license_file(work_dir) -> Path:
         f.write(LICENSE_CONTENTS)
 
     return license_src
-
-
-ORG = "arcana-tests"
-REGISTRY = "a.docker.registry.io"
-IMAGE_VERSION = "1.0"
-
-
-LICENSE_CONTENTS = "license contents"
-
-LICENSE_NAME = "testlicense"
-
-LICENSE_INPUT_FIELD = "license_file"
-
-LICENSE_OUTPUT_FIELD = "validated_license_file"
-
-LICENSE_PATH_PARAM = "license_path"
-
-LICENSE_INPUT_PATH = "contents-file"
-
-LICENSE_OUTPUT_PATH = "validated-file"
