@@ -56,11 +56,13 @@ class EntryBlueprint(metaclass=ABCMeta):
         if self.ids and row.id not in self.ids:
             return
         item = self.make_item(**kwargs)
+        logger.debug("Creating entry at %s in %s", self.path, row)
         entry = row.dataset.store.create_entry(
             path=self.path,
             datatype=self.datatype,
             row=row,
         )
+        logger.debug("Putting %s at %s", item, entry)
         row.dataset.store.put(item, entry)
 
 
@@ -143,7 +145,9 @@ class FileSetEntryBlueprint(EntryBlueprint):
                         zfile.write(next_path)
                     (tmp_dir / next_path).unlink()
             out_paths.append(out_path)
-        return self.datatype(out_paths)
+        item = self.datatype(out_paths)
+        logger.debug("Created %s item", item)
+        return item
 
 
 @attrs.define(kw_only=True)
@@ -168,7 +172,9 @@ class TestDatasetBlueprint:
     dim_lengths: list[int]  # size of layers a-d respectively
     entries: list[EntryBlueprint] = attrs.field(factory=list)
     derivatives: list[EntryBlueprint] = attrs.field(factory=list)
-    id_composition: dict[str, str] = attrs.field(factory=dict)
+    id_patterns: dict[str, str] = attrs.field(factory=dict)
+    include: dict[str, ty.Union[str, list[str]]] = attrs.field(factory=dict)
+    exclude: dict[str, ty.Union[str, list[str]]] = attrs.field(factory=dict)
 
     DEFAULT_NUM_ACCESS_ATTEMPTS = 300
     DEFAULT_ACCESS_ATTEMPT_INTERVAL = 1.0  # secs
@@ -205,21 +211,33 @@ class TestDatasetBlueprint:
         orig_type = metadata.get("type", "test")
         metadata["type"] = "in-construction"
         with store.connection:
+            logger.debug(
+                "Creating test dataset in %s at %s from %s", store, dataset_id, self
+            )
+            if self.id_patterns:
+                kwargs = {"id_patterns": self.id_patterns}
             dataset = store.create_dataset(
                 id=dataset_id,
                 leaves=self.all_ids,
                 name=name,
                 hierarchy=self.hierarchy,
-                id_composition=self.id_composition,
                 space=self.space,
                 metadata=metadata,
+                include=self.include,
+                exclude=self.exclude,
                 **kwargs,
             )
+        with store.connection:
+            logger.debug(
+                "Adding entries to test dataset for: %s",
+                dataset.rows(frequency=max(self.space)),
+            )
             for row in dataset.rows(frequency=max(self.space)):
                 self.make_entries(row, source_data=source_data)
             dataset.metadata.type = orig_type
             dataset.save()
         dataset.__annotations__["blueprint"] = self
+        logger.debug("Successfully created test dataset at %s in %s", dataset_id, store)
         return dataset
 
     def translate_to(self, data_store: DataStore) -> "TestDatasetBlueprint":
@@ -335,6 +353,7 @@ class TestDatasetBlueprint:
         **kwargs
             passed directly through to the EntryBlueprint.create_item method
         """
+        logger.debug("making entries for %s: %s", row, self.entries)
         for entry_bp in self.entries:
             entry_bp.make_entry(row, **kwargs)
 
@@ -483,9 +502,11 @@ TEST_DATASET_BLUEPRINTS = {
         space=TestDataSpace,
         hierarchy=["bc", "ad"],
         dim_lengths=[2, 3, 2, 4],
-        id_composition={
-            "bc": r"b(?P<b>\d+)c(?P<c>\d+)",
-            "ad": r"a(?P<a>\d+)d(?P<d>\d+)",
+        id_patterns={
+            "a": r"ad::a(\d+)d\d+",
+            "b": r"bc::b(\d+)c\d+",
+            "c": r"bc::b\d+c(\d+)",
+            "d": r"ad::a\d+d(\d+)",
         },
         entries=[
             FileSetEntryBlueprint(
@@ -505,9 +526,11 @@ TEST_DATASET_BLUEPRINTS = {
             "abcd",
         ],  # e.g. XNAT where session ID is unique in project but final layer is organised by timepoint
         dim_lengths=[3, 4, 5, 6],
-        id_composition={
-            "abc": r"a(?P<a>\d+)b(?P<b>\d+)c(?P<c>\d+)",
-            "abcd": r"a\d+b\d+c\d+d(?P<d>\d+)",
+        id_patterns={
+            "a": r"abc::a(\d+)b\d+c\d+",
+            "b": r"abc::a\d+b(\d+)c\d+",
+            "c": r"abc::a\d+b\d+c(\d+)",
+            "d": r"abcd::a\d+b\d+c\d+d(\d+)",
         },
         entries=[
             FileSetEntryBlueprint(
